@@ -18,6 +18,7 @@ module org.elasticsearch.server {
     requires org.elasticsearch.grok;
     requires org.elasticsearch.tdigest;
     requires org.elasticsearch.simdvec;
+    requires org.elasticsearch.entitlement;
     requires hppc;
     requires HdrHistogram;
     requires jopt.simple;
@@ -371,6 +372,8 @@ module org.elasticsearch.server {
     exports org.elasticsearch.telemetry.metric;
     exports org.elasticsearch.cluster.routing.allocation.shards to org.elasticsearch.shardhealth, org.elasticsearch.serverless.shardhealth, org.elasticsearch.serverless.apifiltering;
     exports org.elasticsearch.lucene.spatial;
+    exports org.elasticsearch.inference.configuration;
+    exports org.elasticsearch.monitor.metrics;
 
     opens org.elasticsearch.common.logging to org.apache.logging.log4j.core;
 
@@ -378,7 +381,7 @@ module org.elasticsearch.server {
     provides ErrorOnUnknown with SuggestingErrorOnUnknown;
     provides XContentBuilderExtension with XContentElasticsearchExtension;
     provides CliToolProvider with NodeToolCliProvider, ShardToolCliProvider;
-    provides FeatureSpecification with BulkFeatures, FeatureInfrastructureFeatures, HealthFeatures, TransportFeatures, MetadataFeatures, RestFeatures, IndicesFeatures, RepositoriesFeatures, AllocationStatsFeatures, MapperFeatures, IngestGeoIpFeatures, SearchFeatures, ScriptFeatures, RetrieversFeatures, FileSettingsFeatures;
+    provides FeatureSpecification with BulkFeatures, FeatureInfrastructureFeatures, HealthFeatures, TransportFeatures, MetadataFeatures, RestFeatures, IndicesFeatures, RepositoriesFeatures, AllocationStatsFeatures, MapperFeatures, IngestGeoIpFeatures, SearchFeatures, ScriptFeatures, RetrieversFeatures, FileSettingsFeatures, ClusterStatsFeatures;
     provides PostingsFormat with ES85BloomFilterPostingsFormat, ES87BloomFilterPostingsFormat, ES812PostingsFormat;
     provides DocValuesFormat with ES87TSDBDocValuesFormat;
     provides KnnVectorsFormat with ES813FlatVectorFormat, ES813Int8FlatVectorFormat, ES814HnswScalarQuantizedVectorsFormat, ES815HnswBitVectorsFormat, ES815BitFlatVectorFormat, ES816BinaryQuantizedVectorsFormat, ES816HnswBinaryQuantizedVectorsFormat;
